@@ -1,8 +1,8 @@
 #' Q-Q Plot censored data
 #'
 #' @description Plots a quantile-quantile (Q-Q) plot of censored data versus a fitted data distribution
-#' @param y.var The column of `y` (response variable) values plus detection limits
-#' @param cen.var The column of indicators, where 1 (or `TRUE`) indicates a detection limit in the `y.var` column, and 0 (or `FALSE`) indicates a detected value in `y.var`.
+#' @param x.var The column of `x` (response variable) values plus detection limits
+#' @param cens.var The column of indicators, where 1 (or `TRUE`) indicates a detection limit in the `y.var` column, and 0 (or `FALSE`) indicates a detected value in `y.var`.
 #' @param dist One of three distributional shapes to fit to your data:  lognormal (`lnorm`), normal (`norm`) or gamma (`gamma`).
 #' @param Yname Optional – input text in quotes to be used as the variable name on the Q-Q plot.  The default is the `Yname` name of the `y.var` input variable.
 #' @export
@@ -27,11 +27,14 @@
 
 
 
-cenQQ <- function(y.var, cen.var, dist = "lnorm", Yname = yname)  {
+cenQQ <- function(x.var, cens.var, dist = "lnorm", Yname = yname)  {
   #added to stop if dist is not from the list
   #if(!(dist%in%c("norm","lnorm","gamma"))){stop(paste0(dist," distribution is not supported with this function, try again."))}
 
-  yname <- deparse(substitute(y.var))
+  ydat <- na.omit(data.frame(x.var, cens.var))
+  y.var <- ydat[,1];  cen.var <- ydat[,2]
+
+  yname <- deparse(substitute(x.var))
   cen.logical <- as.logical(cen.var)
 
   if (sum(as.integer(cen.var)) > 0)    # not all data are detects
@@ -82,3 +85,4 @@ cenQQ <- function(y.var, cen.var, dist = "lnorm", Yname = yname)  {
     mtext(gamma.text)
   } }
 }
+
